import { useRef, useState, useEffect } from 'react';
import { connect, history } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown
} from '@ant-design/pro-components';
import { Button, Image, ConfigProvider } from 'antd';
import { getCompanyList, GetCompanyInfo } from '@/apis/api';
import { Imageprefix } from '@/constants';

const PagesMainCompanyListTable: React.FC = ({ dispatch, openModel, getId }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                        colorLink: '#4FBE70',
                    }
                }}
            >
                <ProTable
                    scroll={{ x: 1300 }}
                    actionRef={actionRef}
                    dataSource={list}
                    columns={[
                        {
                            title: 'ID',
                            dataIndex: 'id',
                            width: 100,
                            fixed: 'left',
                        },
                        {
                            title: '企业名称',
                            dataIndex: 'full_name',
                            width: 300,
                            fixed: 'left',
                        },
                        {
                            title: '来源',
                            dataIndex: 'origin_text',
                            search: false,
                            width: 100,
                        },
                        {
                            title: '登录次数',
                            dataIndex: 'login_count',
                            search: false,
                            width: 100
                        },
                        {
                            title: '点击次数',
                            dataIndex: 'click_count',
                            search: false,
                            width: 100
                        },
                        {
                            title: '会员类型',
                            dataIndex: 'member_type_text',
                            width: 100,
                            render: (_, record) => (<>
                                {
                                    record.member_type_text && <Button type="primary" size='small' onClick={() => {
                                        sessionStorage.setItem('vip_company_info', JSON.stringify(record))
                                        history.push({
                                            pathname: '/main/company/vip'
                                        })
                                    }}>
                                        {record.member_type_text}
                                    </Button>
                                }

                            </>),
                            valueType: 'select',
                            valueEnum: {
                                0: { text: '全部' },
                                1: {
                                    text: '试用申请中',
                                },
                                2: {
                                    text: '试用正式',
                                },
                                3: {
                                    text: '普通申请中',
                                },
                                4: {
                                    text: '普通正式',
                                },
                                5: {
                                    text: 'VIP申请中',
                                },
                                6: {
                                    text: 'VIP正式',
                                },
                            },
                        },
                        {
                            title: '开始时间',
                            dataIndex: 'start_date',
                            search: false,

                            width: 200
                        },
                        {
                            title: '到期时间',
                            dataIndex: 'end_date',
                            search: false,

                            width: 200
                        }, {
                            title: '剩余点数',
                            dataIndex: 'code',
                            search: false,
                            width: 100
                        },
                        {
                            title: '会员状态',
                            dataIndex: 'member_status_text',
                            width: 100,
                            valueType: 'select',
                            valueEnum: {
                                0: { text: '全部' },
                                1: {
                                    text: '待审',
                                },
                                2: {
                                    text: '正常',
                                },
                                3: {
                                    text: '到期',
                                },
                                4: {
                                    text: '推荐',
                                }
                            },
                        },
                        {
                            title: '企业照片',
                            dataIndex: 'photo',
                            search: false,
                            width: 200,
                            render: (_, record) => (<>
                                <Image src={`${Imageprefix + record.photo}`} width='100%' height={40} preview={false} />
                            </>
                            )
                        }, {
                            title: '照片审核',
                            dataIndex: 'photo_status_text',
                            search: false,

                            width: 100
                        },
                        {
                            title: '营业执照',
                            dataIndex: 'license_path',
                            search: false,

                            width: 200,
                            render: (_, record) => (<>
                                <Image src={`${Imageprefix}${record.license_path}`} width='100%' height={40} preview={false} />
                            </>
                            )
                        },
                        {
                            title: '营业执照审核',
                            dataIndex: 'license_status_text',
                            search: false,
                            width: 200
                        },
                        {
                            title: '登录账号',
                            dataIndex: 'login_name',
                            width: 200
                        },
                        {
                            title: '操作',
                            width: 300,
                            key: 'option',
                            valueType: 'option',
                            fixed: 'right',
                            render: (_, record, action) => [
                                <Button key='1' type='link' onClick={() => {
                                    setId(record.id)
                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>编辑</Button>,
                                <Button key='2' type='link' onClick={() => {
                                    GetCompanyInfo({ id: record.id }).then(res => {
                                        sessionStorage.setItem('company_info', JSON.stringify(res.data))
                                        history.push({
                                            pathname: '/main/company/department'
                                        })
                                    })
                                }}>查看部门</Button>,
                                <TableDropdown
                                    key="actionGroup"
                                    menus={[
                                        {
                                            name: '查看职位',
                                            key: '3',
                                            onClick: () => {
                                                GetCompanyInfo({ id: record.id }).then(res => {
                                                    sessionStorage.setItem('post_company_info', JSON.stringify(res.data))
                                                    history.push({
                                                        pathname: '/main/company/post'
                                                    })
                                                })
                                            },
                                        },
                                        {
                                            name: '子账号解绑',
                                            key: '4',
                                            onClick: () => {

                                            },
                                        },
                                    ]}
                                />,
                            ],
                        },
                    ]}
                    rowKey="id"
                    pagination={{
                        current: page,
                        pageSize: pageSize,
                        showSizeChanger: true,
                        total: total,
                        pageSizeOptions: [9, 18, 27, 99],
                        onChange(page, pageSize) {
                            setPage(page)
                            setPageSize(pageSize)
                        },
                        onShowSizeChange(current, size) {
                            setPage(current)
                            setPageSize(size)
                        }
                    }}
                    request={async (params = {} as Record<string, any>) =>
                        getCompanyList({
                            page: page,
                            pagesize: pageSize,
                            sort: 'id',
                            sortby: 'desc',
                            keyword: params.full_name,
                        }).then(res => {
                            setList(res.data.list)
                            setTotal(res.data.total)
                        })
                    }
                    headerTitle="企业列表"
                    toolBarRender={() => [
                        <Button type="primary" onClick={() => {
                            dispatch({ type: 'openModel/getOpenModal', payload: true })
                        }}>
                            添加企业
                        </Button>
                    ]}
                />
            </ConfigProvider>
        </>
    );
};


export default connect(({ openModel }: any) => ({
    openModel
}))(PagesMainCompanyListTable);