import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType} from '@ant-design/pro-components';
import {
    ProTable
} from '@ant-design/pro-components';
import { Button,  ConfigProvider, Image } from 'antd';
import { PostJobseekerList } from '@/apis/api';
import { Imageprefix } from '@/constants';

const PagesMainInformationArticleTable: React.FC = ({ dispatch,getId, openModel }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])
    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                    }
                }}
            >

                <ProTable
                    scroll={{ x: 1300 }}
                    actionRef={actionRef}
                    dataSource={list}
                    columns={[
                        {
                            title: '姓名',
                            dataIndex: 'seekername'
                        }, {
                            title: '性别',
                            dataIndex: 'gender'
                        }, {
                            title: '教育程度',
                            dataIndex: 'education_txt'
                        }, {
                            title: '手机号',
                            dataIndex: 'mobile'
                        },
                        {
                            title: '审核状态',
                            dataIndex: 'status_txt',
                        },
                        {
                            title: '操作',
                            width: 400,
                            key: 'option',
                            valueType: 'option',
                            fixed: 'right',
                            render: (_, record, action) => [
                                <Button key='1' type='link' onClick={() => {
                                    setId(record)

                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>编辑</Button>,
                                <Button key='2' type='link' onClick={() => {
                                    setId(record)
                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>工作帮扶情况</Button>,
                                // <Button key='2' type='link' onClick={() => {
                                //     setId(record)
                                //     dispatch({ type: 'openModel/getOpenRegisterModal', payload: true })
                                // }}>就业服务登记表</Button>,
                                <Button key='4' type='link' onClick={() => {
                                    setId(record)
                                    dispatch({ type: 'openModel/getOpenExportModal', payload: true })
                                }}>导出登记表</Button>,
                            ],
                        },
                    ]}
                    rowKey="id"
                    pagination={{
                        current: page,
                        pageSize: pageSize,
                        showSizeChanger: true,
                        total: total,
                        pageSizeOptions: [9, 18, 27, 99],
                        onChange(page, pageSize) {
                            setPage(page)
                            setPageSize(pageSize)
                        },
                        onShowSizeChange(current, size) {
                            setPage(current)
                            setPageSize(size)
                        }
                    }}
                    request={async (params = {} as Record<string, any>) =>
                        PostJobseekerList({
                            page: page,
                            pagesize: pageSize,
                            sort: 'id',
                            sortby: 'desc',
                            keyword: params.name,
                      
                        }).then(res => {
                            setList(res.data.seekers)
                            setTotal(res.data.total)
                        })
                    }
                    headerTitle="简历列表"
                />
            </ConfigProvider>

        </>



    );
};


export default connect(({ dictModel , openModel}: any) => ({
    dictModel,
    openModel
}))(PagesMainInformationArticleTable);