
import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProFormText,
    ProFormSegmented,
    ProFormSelect,
    ProForm,
    FormControlRender,
    ProFormDependency,
    ProFormSwitch
} from '@ant-design/pro-components';
import { ConfigProvider, Flex, Space, Modal, message, Image, Row, Col, Switch, Form, Typography } from 'antd';
import { GetRoleList, addAccount, updateAccount } from '@/apis/api';
import { Imageprefix } from '@/constants';
import UploadModel from '@/components/Common/upload';


const selectfieldNames = { label: 'name', value: 'id' };


const PagesMainInformationArticleCreate: React.FC = ({ dispatch, dictModel, openModel, id }: any) => {
    const formRef = useRef<ProFormInstance>();
    const [openPreview, setOpenPreview] = useState(false);
    const [detail, setDetail] = useState<PermissionType.account | null>(null)

    useEffect(() => {
        setOpenPreview(openModel.openModal)
    }, [openModel.openModal])

    const [uploadedFilephotoName, setUploadedFilephotoName] = useState<string>('');
    const handleFileUploadedphoto = (filename: string) => {
        setUploadedFilephotoName(filename);
    };

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                    }
                }}
            >
                <Modal
                    open={openPreview}
                    title={id ? '编辑账号' : '添加账号'}
                    centered
                    maskClosable={false}
                    footer={null}
                    destroyOnClose
                    width={1000}
                    onCancel={() => {
                        dispatch({ type: 'openModel/getOpenModal', payload: false })
                    }}
                >
                    <ProForm<PermissionType.account>
                        formRef={formRef}
                        request={async () => {
                            if (id) {
                                let res = await GetArticleDetail({ id: id })
                                return res.data;
                            } else {
                                return {
                                    mobile: '',
                                    password: '',
                                    repassword: '',
                                    nickname: '',
                                    avatar: '',
                                    email: '',
                                    roleids: '',
                                }
                            }
                        }}
                        submitter={{
                            searchConfig: {
                                resetText: '取消',
                                submitText: '保存',
                            },
                            render: (_, dom) => { return <Flex justify='flex-end'> <Space>{dom}</Space></Flex> },
                            onReset: () => {
                                setDetail(null)
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                        onFinish={async (values) => {
                            console.log(values)
                            if (id) {
                                values.id = id;
                                let res = await updateAccount(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            } else {
                                let res = await addAccount(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                    >
                        <ProFormText
                            label="手机号"
                            name="mobile"
                            placeholder="请输入手机号"
                            rules={[{ required: true, message: '请输入手机号' }]}
                        />

                        <ProFormText
                            label="密码"
                            name="password"
                            placeholder="请输入密码"
                            rules={[{ required: true, message: '请输入密码' }]}
                        />
                        <ProFormText
                            label="确认密码"
                            name="repassword"
                            placeholder="请输入确认密码"
                            rules={[{ required: true, message: '请输入确认密码' }]}
                        />
                        <ProFormText
                            label="昵称"
                            name="nickname"
                            placeholder="请输入昵称"
                        />
                        <Row gutter={[16, 16]}>
                            {
                                detail ?
                                    <Col span={4}>
                                        <UploadModel multiple={false} form_name="avatar" image_length={1} uploadTxt="上传头像" image_type={1} onUploadComplete={handleFileUploadedphoto}></UploadModel>
                                    </Col> : <>
                                        <Col span={4}>
                                            <UploadModel multiple={false} form_name="avatar" image_length={1} uploadTxt="上传头像" image_type={1} onUploadComplete={handleFileUploadedphoto}></UploadModel>
                                        </Col>
                                    </>
                            }
                            {
                                detail ?
                                    <Col span={4}>
                                        {uploadedFilephotoName ? <Image src={`${Imageprefix}${uploadedFilephotoName}`} style={{ marginBottom: '16px', width: '100px', height: '100px' }}></Image> : <Image src={`${Imageprefix}${detail?.avatar}`} style={{ marginTop: '16px', width: '200px', height: '200px' }}></Image>}
                                    </Col> : <>
                                        {uploadedFilephotoName ? <Col span={4}> <Image src={`${Imageprefix}${uploadedFilephotoName}`} style={{ marginTop: '32px', width: '100px', height: '100px' }}></Image> </Col> : ''}
                                    </>
                            }
                        </Row>
                        <ProFormText
                            label="邮箱"
                            name="email"
                            placeholder="请输入邮箱"
                        />
                        <ProFormSelect
                            showSearch
                            name="roleids"
                            label="选择角色"
                            placeholder="请选择角色"
                            fieldProps={{
                                fieldNames: selectfieldNames,
                                mode: 'multiple'
                            }}
                            request={(keyword) =>
                                GetRoleList({ page: 1, pagesize: 100, keyword: keyword.keyWords }).then(res => {
                                    return res.data.roles;
                                })
                            }
                        />


                    </ProForm>
                </Modal>
            </ConfigProvider>
        </>
    );
};



export default connect(({ dictModel, openModel }: any) => ({
    dictModel, openModel
}))(PagesMainInformationArticleCreate);