
import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProFormText,
    ProFormSegmented,
    ProFormSelect,
    ProForm,
    FormControlRender,
    ProFormDependency,
    ProFormSwitch
} from '@ant-design/pro-components';
import { ConfigProvider, Flex, Space, Modal, message, Image, Row, Col, Switch, Form, Typography } from 'antd';
import { addArticle, updateArticle, listSection, GetArticleDetail } from '@/apis/api';


const selectfieldNames = { label: 'name', value: 'id' };


const PagesMainInformationArticleCreate: React.FC = ({ dispatch, dictModel, openModel, id }: any) => {
    const formRef = useRef<ProFormInstance>();
    const [openPreview, setOpenPreview] = useState(false);
    const [detail, setDetail] = useState<PermissionType.list | null>(null)

    useEffect(() => {
        setOpenPreview(openModel.openModal)
    }, [openModel.openModal])


    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                    }
                }}
            >
                <Modal
                    open={openPreview}
                    title={id ? '编辑权限/菜单' : '添加权限/菜单'}
                    centered
                    maskClosable={false}
                    footer={null}
                    destroyOnClose
                    width={1000}
                    onCancel={() => {
                        dispatch({ type: 'openModel/getOpenModal', payload: false })
                    }}
                >
                    <ProForm<PermissionType.list>
                        formRef={formRef}
                        request={async () => {
                            if (id) {
                                let res = await GetArticleDetail({ id: id })
                                return res.data;
                            } else {
                                return {
                                    name: '',
                                    path: '',
                                    action: '',
                                    module: '',
                                    p_type: '',
                                    parent_id: 0,
                                    description: '',
                                }
                            }
                        }}
                        submitter={{
                            searchConfig: {
                                resetText: '取消',
                                submitText: '保存',
                            },
                            render: (_, dom) => { return <Flex justify='flex-end'> <Space>{dom}</Space></Flex> },
                            onReset: () => {
                                setDetail(null)
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                        onFinish={async (values) => {
                            console.log(values)
                            if (id) {
                                values.id = id;
                                let res = await updateArticle(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            } else {
                                let res = await addArticle(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                    >
                        <ProFormText
                            label="权限/菜单名称"
                            name="title"
                            placeholder="请输入权限/菜单名称"
                            rules={[{ required: true, message: '请输入权限/菜单名称' }]}
                        />
                        <ProFormText
                            label="路径"
                            name="path"
                            placeholder="请输入路径"
                            rules={[{ required: true, message: '请输入路径' }]}
                        />
                        <ProFormText
                            label="标识名称"
                            name="action"
                            placeholder="请输入标识名称"
                            rules={[{ required: true, message: '请输入标识名称' }]}
                        />
                        <ProFormText
                            label="指向页面"
                            name="module"
                            placeholder="请输入指向页面"
                            rules={[{ required: true, message: '请输入指向页面' }]}
                        />
                        <ProFormSegmented
                            name="p_type"
                            label="权限类型"
                            request={async () => [
                                { label: '权限', value: 1 },
                                { label: '菜单', value: 2 }
                            ]}
                            rules={[{ required: true, message: '请选择是否置顶' }]}
                        />
                        <ProFormSegmented
                            name="parent_id"
                            label="是否是顶级菜单"
                            request={async () => [
                                { label: '是', value: -1 },
                                { label: '否', value: 0 }
                            ]}
                            rules={[{ required: true, message: '请选择是否是顶级菜单' }]}
                        />

                        <ProFormText
                            name="description"
                            label="描述"
                            placeholder="请输入描述"
                        />

                    </ProForm>
                </Modal>
            </ConfigProvider>
        </>
    );
};



export default connect(({ dictModel, openModel }: any) => ({
    dictModel, openModel
}))(PagesMainInformationArticleCreate);