import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType } from '@ant-design/pro-components';
import {
    ProTable
} from '@ant-design/pro-components';
import { Button, ConfigProvider, Tag } from 'antd';
import { getPermissionListWithchilds } from '@/apis/api';

const PagesMainInformationArticleTable: React.FC = ({ dispatch, getId, openModel }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])
    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                    }
                }}
            >

                <ProTable
                    scroll={{ x: 1300 }}
                    actionRef={actionRef}
                    dataSource={list}
                    columns={[
                        {
                            title: '权限/菜单',
                            dataIndex: 'name',
                            width: 300,
                            render: (_, record) => (<>
                                {record.p_type == 1 ? <>{record.name} <Tag>权限</Tag></> : <>{record.name} <Tag>菜单</Tag></>}
                            </>
                            )
                        }, {
                            title: '路径',
                            dataIndex: 'path',
                            search: false
                        }, {
                            title: '标识名称',
                            dataIndex: 'action',
                            search: false
                        }, {
                            title: '指向页面',
                            dataIndex: 'module',
                            search: false
                        }, {
                            title: '上级菜单id',
                            dataIndex: 'parent_id',
                            search: false,
                            render: (_, record) => (<>
                                {record.parent_id == -1 ? '当前已是顶级菜单' : record.parent_id}
                            </>
                            )
                        }, {
                            title: '描述',
                            dataIndex: 'description',
                            search: false
                        },
                        {
                            title: '操作',
                            width: 300,
                            key: 'option',
                            valueType: 'option',
                            fixed: 'right',
                            render: (_, record, action) => [
                                <>
                                    <Button key='1' type='link' onClick={() => {
                                        setId(record.id)
                                        dispatch({ type: 'openModel/getOpenModal', payload: true })
                                    }}>编辑</Button>
                                    {
                                        record.p_type == 2 && <Button key='2' type='link' onClick={() => {

                                        }}>添加下级菜单</Button>
                                    }
                                </>


                            ],
                        },
                    ]}
                    rowKey="id"
                    pagination={{
                        current: page,
                        pageSize: pageSize,
                        showSizeChanger: true,
                        total: total,
                        pageSizeOptions: [9, 18, 27, 99],
                        onChange(page, pageSize) {
                            setPage(page)
                            setPageSize(pageSize)
                        },
                        onShowSizeChange(current, size) {
                            setPage(current)
                            setPageSize(size)
                        }
                    }}
                    request={async (params = {} as Record<string, any>) =>
                        getPermissionListWithchilds({
                            page: page,
                            pagesize: pageSize,
                            sort: 'id',
                            sortby: 'desc',
                            keyword: params.name,

                        }).then(res => {
                            setList(res.data.permissions)
                            setTotal(res.data.total)
                        })
                    }
                    headerTitle="权限列表"
                    toolBarRender={() => [
                        <Button type="primary" onClick={() => {
                            dispatch({ type: 'openModel/getOpenModal', payload: true })
                        }}>
                            添加权限
                        </Button>
                    ]}
                    expandable={{
                        childrenColumnName: 'childs', // 指定子节点数据的字段名
                    }}
                />
            </ConfigProvider>

        </>



    );
};


export default connect(({ dictModel, openModel }: any) => ({
    dictModel,
    openModel
}))(PagesMainInformationArticleTable);