
import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProFormText,
    ProFormSegmented,
    ProFormSelect,
    ProForm,
    FormControlRender,
    ProFormDependency,
    ProFormSwitch
} from '@ant-design/pro-components';
import { ConfigProvider, Flex, Space, Modal, message, Image, Row, Col, Switch, Form, Typography } from 'antd';
import { PostDictAdd, PostDictUpdate } from '@/apis/api';
import { Imageprefix } from '@/constants';
import UploadModel from '@/components/Common/upload';


const selectfieldNames = { label: 'name', value: 'id' };


const PagesMainInformationArticleCreate: React.FC = ({ dispatch, dictModel, openModel, id }: any) => {
    const formRef = useRef<ProFormInstance>();
    const [openPreview, setOpenPreview] = useState(false);
    const [detail, setDetail] = useState<SettingType.dict | null>(null)

    useEffect(() => {
        setOpenPreview(openModel.openModal)
    }, [openModel.openModal])

    const [uploadedFilephotoName, setUploadedFilephotoName] = useState<string>('');
    const handleFileUploadedphoto = (filename: string) => {
        setUploadedFilephotoName(filename);
    };

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                    }
                }}
            >
                <Modal
                    open={openPreview}
                    title={id ? '编辑字典' : '添加字典'}
                    centered
                    maskClosable={false}
                    footer={null}
                    destroyOnClose
                    width={1000}
                    onCancel={() => {
                        dispatch({ type: 'openModel/getOpenModal', payload: false })
                    }}
                >
                    <ProForm<SettingType.dict>
                        formRef={formRef}
                        request={async () => {
                            if (id) {
                                let res = await GetArticleDetail({ id: id })
                                return res.data;
                            } else {
                                return {
                                    code: '',
                                    parent_id: -1,
                                    name: '',
                                    value: '',
                                    display: '',
                                    childs: null,
                                }
                            }
                        }}
                        submitter={{
                            searchConfig: {
                                resetText: '取消',
                                submitText: '保存',
                            },
                            render: (_, dom) => { return <Flex justify='flex-end'> <Space>{dom}</Space></Flex> },
                            onReset: () => {
                                setDetail(null)
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                        onFinish={async (values) => {
                            console.log(values)
                            if (id) {
                                values.id = id;
                                let res = await PostDictUpdate(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            } else {
                                let res = await PostDictAdd(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                    >
                        <ProFormText
                            label="字典名"
                            name="name"
                            placeholder="请输入字典名"
                            rules={[{ required: true, message: '请输入字典名' }]}
                        />

                        <ProFormText
                            label="字典标识名"
                            name="code"
                            placeholder="请输入字典标识名"
                            rules={[{ required: true, message: '请输入字典标识名' }]}
                        />
                        <ProFormText
                            label="字典代码值"
                            name="value"
                            placeholder="请输入字典代码值"
                            rules={[{ required: true, message: '请输入字典代码值' }]}
                        />
                        <ProFormSegmented
                            name="display"
                            label="是否显示"
                            request={async () => [
                                { label: '是', value: 'S' },
                                { label: '否', value: 'H' }
                            ]}
                            rules={[{ required: true, message: '请选择是否显示' }]}
                        />


                    </ProForm>
                </Modal>
            </ConfigProvider>
        </>
    );
};



export default connect(({ dictModel, openModel }: any) => ({
    dictModel, openModel
}))(PagesMainInformationArticleCreate);